import java.io.*;
import java.net.*;

/**
 * A simple demonstration showing how to create graphs from a remote web-service.
 * This example takes a list of one or more XML files as input and creates a
 * matching PNG file as output.
 * 
 * It's currently set to use our demo webserver to convert the XML, although we'd
 * suggest changing the URL to your own installation as we can't promise our demo
 * server will always be up.
 */
public class WebServiceTest
{
    static final String server = "http://big.faceless.org/servlet/GraphServlet/xml-raw";

    public static void main(String[] args) throws IOException {
        if (args.length==0) {
            System.out.println("Usage: java WebServiceTest <file1.xml> [<file2.xml> ...]\n");
        } else {
            for (int i=0;i<args.length;i++) {
                String in = args[i];
                String out = in.endsWith(".xml") ? in.substring(0, in.length()-4)+".png" : in+".png";
                writeGraph(getGraph(readXML(in)), out);
            }
        }
    }

    /**
     * Read the XML from the specified file
     */
    static byte[] readXML(String name) throws IOException {
        System.out.print("Reading \""+name+"\"");
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        int c;
        FileInputStream in = new FileInputStream(name);
        while ((c=in.read())>=0) out.write(c);
        return out.toByteArray();
    }

    /**
     * Given the XML, convert it to a Graph by using the "xml-raw" web service
     */
    static InputStream getGraph(byte[] xml) throws IOException {
        System.out.print("... ");
        URL url = new URL(server);
        URLConnection con = url.openConnection();
        con.setDoOutput(true);
        con.getOutputStream().write(xml);
        con.getOutputStream().close();
        return con.getInputStream();
    }

    /**
     * Given the graph returned from the web service, save it to a file
     */
    static void writeGraph(InputStream in, String name) throws IOException {
        System.out.print("Writing \""+name+"\"");
        FileOutputStream out = new FileOutputStream(name);
        int c;
        while ((c=in.read())>=0) out.write(c);
        out.close();
        in.close();
        System.out.println();
    }
}
